unit Main;

interface

uses Windows, SysUtils, Classes, Graphics, Forms, Controls, Menus,
  StdCtrls, Dialogs, Buttons, Messages, ExtCtrls, ComCtrls,
  DecoratedStatusBar, DecoratedForm, StatusBarAbout;

type
  TExemple = class(TForm)
    MainMenu1: TMainMenu;
    File1: TMenuItem;
    FileNewItem: TMenuItem;
    FileOpenItem: TMenuItem;
    FileCloseItem: TMenuItem;
    Window1: TMenuItem;
    Help1: TMenuItem;
    N1: TMenuItem;
    FileExitItem: TMenuItem;
    WindowCascadeItem: TMenuItem;
    WindowTileItem: TMenuItem;
    WindowArrangeItem: TMenuItem;
    HelpAboutItem: TMenuItem;
    OpenDialog: TOpenDialog;
    FileSaveItem: TMenuItem;
    FileSaveAsItem: TMenuItem;
    Edit1: TMenuItem;
    CutItem: TMenuItem;
    CopyItem: TMenuItem;
    PasteItem: TMenuItem;
    WindowMinimizeItem: TMenuItem;
    SpeedPanel: TPanel;
    OpenBtn: TSpeedButton;
    SaveBtn: TSpeedButton;
    CutBtn: TSpeedButton;
    CopyBtn: TSpeedButton;
    PasteBtn: TSpeedButton;
    ExitBtn: TSpeedButton;
    OpenDialog1: TOpenDialog;
    StatusBar: TDecoratedStatusBar;
    DecoratedDigitalClock1: TDecoratedDigitalClock;
    DecoratedControlKeyboard1: TDecoratedControlKeyboard;
    DecoratedControlKeyboard2: TDecoratedControlKeyboard;
    DecoratedControlKeyboard3: TDecoratedControlKeyboard;
    PopupMenu1: TPopupMenu;
    PopupMenu2: TPopupMenu;
    PopupMenu3: TPopupMenu;
    PopupMenu4: TPopupMenu;
    Show1: TMenuItem;
    Relief1: TMenuItem;
    Modified1: TMenuItem;
    Num1: TMenuItem;
    Caps1: TMenuItem;
    Ins1: TMenuItem;
    procedure FormCreate(Sender: TObject);
    procedure FileNewItemClick(Sender: TObject);
    procedure WindowCascadeItemClick(Sender: TObject);
    procedure UpdateMenuItems(Sender: TObject);
    procedure WindowTileItemClick(Sender: TObject);
    procedure WindowArrangeItemClick(Sender: TObject);
    procedure FileCloseItemClick(Sender: TObject);
    procedure FileOpenItemClick(Sender: TObject);
    procedure FileExitItemClick(Sender: TObject);
    procedure FileSaveItemClick(Sender: TObject);
    procedure FileSaveAsItemClick(Sender: TObject);
    procedure CutItemClick(Sender: TObject);
    procedure CopyItemClick(Sender: TObject);
    procedure PasteItemClick(Sender: TObject);
    procedure WindowMinimizeItemClick(Sender: TObject);
    procedure FormDestroy(Sender: TObject);
    procedure StatusBarResize(Sender: TObject);
    procedure Show1Click(Sender: TObject);
    procedure Relief1Click(Sender: TObject);
    procedure Modified1Click(Sender: TObject);
    procedure Num1Click(Sender: TObject);
    procedure Caps1Click(Sender: TObject);
    procedure Ins1Click(Sender: TObject);
    procedure StatusBarPanelEnter(Panel: Integer);
    procedure DecoratedControlKeyboard1MouseMove(Sender: TObject;
      Shift: TShiftState; X, Y: Integer);
    procedure DecoratedControlKeyboard2MouseMove(Sender: TObject;
      Shift: TShiftState; X, Y: Integer);
    procedure DecoratedControlKeyboard3MouseMove(Sender: TObject;
      Shift: TShiftState; X, Y: Integer);
    procedure DecoratedDigitalClock1MouseMove(Sender: TObject;
      Shift: TShiftState; X, Y: Integer);
    procedure HelpAboutItemClick(Sender: TObject);
  private
    { Private declarations }
    procedure CreateMDIChild(const Name: string);
    procedure ShowHint(Sender: TObject);
  public
    { Public declarations }
  end;

var
  Exemple: TExemple;

implementation

{$R *.DFM}

uses ChildWin;

procedure TExemple.FormCreate(Sender: TObject);
begin
  Application.OnHint := ShowHint;
  Screen.OnActiveFormChange := UpdateMenuItems;
  DecoratedControlKeyboard1.left := Width - 231;
  DecoratedControlKeyboard2.left := Width - 183;
  DecoratedControlKeyboard3.left := Width - 135;
  DecoratedDigitalClock1.left    := Width - 81;
  StatusBar.Panels[0].Color       := clOlive;
end;

procedure TExemple.ShowHint(Sender: TObject);
begin
  StatusBar.SimpleText := Application.Hint;
end;

procedure TExemple.CreateMDIChild(const Name: string);
var
  Child: TMDIChildTest;
begin
  { create a new MDI child window }
  Child := TMDIChildTest.Create(Application);
  Child.Caption := Name;
end;

procedure TExemple.FileNewItemClick(Sender: TObject);
begin
  CreateMDIChild('NONAME' + IntToStr(MDIChildCount + 1));
end;

procedure TExemple.FileOpenItemClick(Sender: TObject);
begin
  if OpenDialog.Execute then
     CreateMDIChild(OpenDialog.FileName);
end;

procedure TExemple.FileCloseItemClick(Sender: TObject);
begin
  if ActiveMDIChild <> nil then
    ActiveMDIChild.Close;
end;

procedure TExemple.FileSaveItemClick(Sender: TObject);
begin
  { save current file (ActiveMDIChild points to the window) }
end;

procedure TExemple.FileSaveAsItemClick(Sender: TObject);
begin
  { save current file under new name }
end;

procedure TExemple.FileExitItemClick(Sender: TObject);
begin
  Close;
end;

procedure TExemple.CutItemClick(Sender: TObject);
begin
  {cut selection to clipboard}
end;

procedure TExemple.CopyItemClick(Sender: TObject);
begin
  {copy selection to clipboard}
end;

procedure TExemple.PasteItemClick(Sender: TObject);
begin
  {paste from clipboard}
end;

procedure TExemple.WindowCascadeItemClick(Sender: TObject);
begin
  Cascade;
end;

procedure TExemple.WindowTileItemClick(Sender: TObject);
begin
  Tile;
end;

procedure TExemple.WindowArrangeItemClick(Sender: TObject);
begin
  ArrangeIcons;
end;

procedure TExemple.WindowMinimizeItemClick(Sender: TObject);
var
  I: Integer;
begin
  { Must be done backwards through the MDIChildren array }
  for I := MDIChildCount - 1 downto 0 do
    MDIChildren[I].WindowState := wsMinimized;
end;

procedure TExemple.UpdateMenuItems(Sender: TObject);
begin
  FileCloseItem.Enabled := MDIChildCount > 0;
  FileSaveItem.Enabled := MDIChildCount > 0;
  FileSaveAsItem.Enabled := MDIChildCount > 0;
  CutItem.Enabled := MDIChildCount > 0;
  CopyItem.Enabled := MDIChildCount > 0;
  PasteItem.Enabled := MDIChildCount > 0;
  SaveBtn.Enabled := MDIChildCount > 0;
  CutBtn.Enabled := MDIChildCount > 0;
  CopyBtn.Enabled := MDIChildCount > 0;
  PasteBtn.Enabled := MDIChildCount > 0;
  WindowCascadeItem.Enabled := MDIChildCount > 0;
  WindowTileItem.Enabled := MDIChildCount > 0;
  WindowArrangeItem.Enabled := MDIChildCount > 0;
  WindowMinimizeItem.Enabled := MDIChildCount > 0;
end;

procedure TExemple.FormDestroy(Sender: TObject);
begin
  Screen.OnActiveFormChange := nil;
end;

procedure TExemple.StatusBarResize(Sender: TObject);
begin
  DecoratedControlKeyboard1.left := Width - 231;
  DecoratedControlKeyboard2.left := Width - 183;
  DecoratedControlKeyboard3.left := Width - 135;
  DecoratedDigitalClock1.left    := Width - 81;
end;

procedure TExemple.Show1Click(Sender: TObject);
begin
  Show1.Checked := not Show1.Checked;
  DecoratedDigitalClock1.Visible := Show1.Checked;
end;

procedure TExemple.Relief1Click(Sender: TObject);
begin
  Relief1.Checked := not Relief1.Checked;
  StatusBar.Relief := Relief1.Checked;
end;

procedure TExemple.Modified1Click(Sender: TObject);
begin
  Modified1.Checked := not Modified1.Checked;
  if ( Modified1.Checked ) then StatusBar.Panels[0].Text := 'Modified'
                           else StatusBar.Panels[0].Text := '';
  StatusBar.Repaint;
end;

procedure TExemple.Num1Click(Sender: TObject);
begin
  Num1.Checked := not Num1.Checked;
  DecoratedControlKeyboard1.Visible := Num1.Checked;
end;

procedure TExemple.Caps1Click(Sender: TObject);
begin
  Caps1.Checked := not Caps1.Checked;
  DecoratedControlKeyboard2.Visible := Caps1.Checked;
end;

procedure TExemple.Ins1Click(Sender: TObject);
begin
  Ins1.Checked := not Ins1.Checked;
  DecoratedControlKeyboard3.Visible := Ins1.Checked;
end;

procedure TExemple.StatusBarPanelEnter(Panel: Integer);
begin
  case Panel of
    3 : StatusBar.PopupMenu := PopupMenu1;
    2 : StatusBar.PopupMenu := PopupMenu2;
    1 : StatusBar.PopupMenu := PopupMenu3;
    0 : StatusBar.PopupMenu := PopupMenu4;
  end;
end;

procedure TExemple.DecoratedControlKeyboard1MouseMove(Sender: TObject;
  Shift: TShiftState; X, Y: Integer);
begin
  StatusBar.PopupMenu := PopupMenu3;
end;

procedure TExemple.DecoratedControlKeyboard2MouseMove(Sender: TObject;
  Shift: TShiftState; X, Y: Integer);
begin
  StatusBar.PopupMenu := PopupMenu3;
end;

procedure TExemple.DecoratedControlKeyboard3MouseMove(Sender: TObject;
  Shift: TShiftState; X, Y: Integer);
begin
  StatusBar.PopupMenu := PopupMenu3;
end;

procedure TExemple.DecoratedDigitalClock1MouseMove(Sender: TObject;
  Shift: TShiftState; X, Y: Integer);
begin
  StatusBar.PopupMenu := PopupMenu4;
end;

procedure TExemple.HelpAboutItemClick(Sender: TObject);
begin
  Application.CreateForm(TDecoratedStatusBarAbout, DecoratedStatusBarAbout);
    DecoratedStatusBarAbout.ShowModal;
end;

end.
